pub struct CSound {
pub sound_id: i32,
pub source: i32,
pub pos: IVec3,
pub volume: f32,
pub pitch: f32,
pub seed: i64,
}Expand description
Sent to play a sound effect at a specific position.
The position is encoded at 8x precision (divide by 8 to get actual block coordinates). This allows sub-block positioning for more accurate sound placement.
Fields
sound_id: i32The holder-encoded sound event ID (VarInt).
Vanilla reserves 0 for direct sound events, so registered sound events
are encoded as registry_id + 1.
source: i32The sound source category (VarInt).
pos: IVec3X position multiplied by 8 (fixed-point).
volume: f32Volume (1.0 = normal).
pitch: f32Pitch (1.0 = normal).
seed: i64Random seed for sound variations.
Implementations
Sourceimpl CSound
impl CSound
Sourcepub fn new(
sound: SoundEventRef,
source: SoundSource,
pos: DVec3,
volume: f32,
pitch: f32,
seed: i64,
) -> Self
pub fn new( sound: SoundEventRef, source: SoundSource, pos: DVec3, volume: f32, pitch: f32, seed: i64, ) -> Self
Creates a new sound packet.
Arguments
sound- Sound event to playsource- Sound source categoryx,y,z- Position in block coordinates (will be scaled by 8)volume- Volume multiplier (1.0 = normal)pitch- Pitch multiplier (1.0 = normal)seed- Random seed for sound variations
Sourcepub fn block_sound(
sound: SoundEventRef,
pos: BlockPos,
volume: f32,
pitch: f32,
seed: i64,
) -> Self
pub fn block_sound( sound: SoundEventRef, pos: BlockPos, volume: f32, pitch: f32, seed: i64, ) -> Self
Creates a block sound packet at the center of a block position.
Arguments
sound- Sound event to playpos- Block position (will be centered at +0.5)volume- Volume multiplierpitch- Pitch multiplierseed- Random seed